summaryrefslogtreecommitdiff
path: root/lisp/ses.el
diff options
context:
space:
mode:
authorStefan Kangas <stefan@marxist.se>2020-09-21 13:29:10 +0200
committerStefan Kangas <stefan@marxist.se>2020-09-21 14:26:42 +0200
commit462dbc1cb2c59eaca9c9344636b8af29462370a0 (patch)
treef5329670eed8372fc268bf7f5037627f0330d81e /lisp/ses.el
parente72d3793bcec67f9312e9d011e4357f8986bf837 (diff)
downloademacs-462dbc1cb2c59eaca9c9344636b8af29462370a0.tar.gz
emacs-462dbc1cb2c59eaca9c9344636b8af29462370a0.tar.bz2
emacs-462dbc1cb2c59eaca9c9344636b8af29462370a0.zip
; Fix typos
Diffstat (limited to 'lisp/ses.el')
-rw-r--r--lisp/ses.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/ses.el b/lisp/ses.el
index a2e603307ed..64d03a7fe5f 100644
--- a/lisp/ses.el
+++ b/lisp/ses.el
@@ -3672,7 +3672,7 @@ highlighted range in the spreadsheet."
;; 'rowcol' corresponding to 'ses-cell' property of symbol
;; 'sym'. Both must be the same.
(unless (eq sym old-name)
- (error "Spreadsheet is broken, both symbols %S and %S refering to cell (%d,%d)" sym old-name row col))
+ (error "Spreadsheet is broken, both symbols %S and %S referring to cell (%d,%d)" sym old-name row col))
(if new-rowcol
;; the new name is of A1 type, so we test that the coordinate
;; inferred from new name
@@ -3685,7 +3685,7 @@ highlighted range in the spreadsheet."
(puthash new-name rowcol ses--named-cell-hashmap))
(push `(ses-rename-cell ,old-name ,cell) buffer-undo-list)
(cl-pushnew rowcol ses--deferred-write :test #'equal)
;; Replace name by new name in formula of cells refering to renamed cell.
(dolist (ref (ses-cell-references cell))
(let* ((x (ses-sym-rowcol ref))
(xcell (ses-get-cell (car x) (cdr x))))
@@ -3685,7 +3685,7 @@ highlighted range in the spreadsheet."
(push `(ses-rename-cell ,old-name ,cell) buffer-undo-list)
(cl-pushnew rowcol ses--deferred-write :test #'equal)
- ;; Replace name by new name in formula of cells refering to renamed cell.
+ ;; Replace name by new name in formula of cells referring to renamed cell.
(dolist (ref (ses-cell-references cell))
(let* ((x (ses-sym-rowcol ref))